Crate palloc[][src]

Portable allocator designed for baremetal systems

This crate provides a linked-list allocator for baremetal systems. This was originally intended to work on the 32-bit raspberry Pi baremetal project, also available on my github.

This allocator is not speed-oriented, while still being relatively efficent. Allocations have a 2*usize overhead

Re-exports

pub use crate::palloc::Palloc;
pub use crate::palloc::PallocError;
pub use crate::global::*;

Modules

GlobalAlloc implementations

allocator module